## Installation

```sh
pip install MusicBGX
```

## Useage

```python
from MusicBGX import *
app = BackGround(paths=['ads1.mp3', 'ads2.mp3])
app.play_background_music()
```

## Project status

- Alpha

## Author

- language programming : Python
- Author  : Amin Rngbr